@@ -784,12 +784,23 @@ expect_status <- function(lambda, drprate, maxstudy, accdur) {
 ##         rndprop - randomisation proportion
 ##
 ## Output: events - the expected number of events
-expect_ev_arm <- function(lambda, drprate, maxstudy, accdur,
-                          totalSS, rndprop) {
-  expst <- expect_status(lambda, drprate, maxstudy, accdur)
-  events <- totalSS * rndprop * expst
-  return(events)
+expect_ev_arm <- function(lambda, drprate, maxstudy, accdur, totalSS, rndprop = 1) {
+  if (accdur <= 0 || maxstudy <= 0) {
+    return(0)
+  }
+  if (accdur > maxstudy) {
+    accdur <- maxstudy
+  }
+  rate_total <- lambda + drprate
+  if (rate_total <= 0) {
+    return(0)
+  }
+  accrual_rate <- totalSS * rndprop / accdur
+  exp_term <- exp(-rate_total * maxstudy)
+  integral <- accdur - exp_term * (exp(rate_total * accdur) - 1) / rate_total
+  accrual_rate * (lambda / rate_total) * integral
 }
+
 #------------------------------------------------------------------------
 #gsNormalGrid
 #-------------
@@ -817,12 +828,11 @@ expect_ev_arm <- function(lambda, drprate, maxstudy, accdur,
 #' @export
 #'
 #' @examples
-#' library(dplyr)
 #' # approximate variance of standard normal (i.e., 1)
-#' gridpts() %>% summarize(var = sum(z^2 * w * dnorm(z)))
+#' gridpts() |> dplyr::summarize(var = sum(z^2 * w * dnorm(z)))
 #'
 #' # approximate probability above .95 quantile (i.e., .05)
-#' gridpts(a = qnorm(.95), b = Inf) %>% summarize(p05 = sum(w * dnorm(z)))
+#' gridpts(a = qnorm(.95), b = Inf) |> dplyr::summarize(p05 = sum(w * dnorm(z)))
 gridpts <- function(r = 18, mu = 0, a = -Inf, b = Inf){
   # Define odd numbered grid points for real line
   x <- c(mu - 3 - 4 * log(r / (1:(r - 1))),
